import React from 'react';
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { BarChart, Bar, XAxis, YAxis, CartesianGrid, Tooltip, Legend, PieChart, Pie, Cell } from 'recharts';

const FinancialDashboard = () => {
  // Operating Expenses Data
  const expenseData = [
    { name: 'Cost of Sales', value: 171672359 },
    { name: 'Salaries', value: 7500538 },
    { name: 'Operating Overhead', value: 4062861 },
    { name: 'Advertising & PR', value: 2000000 },
    { name: 'R&D', value: 1405036 },
    { name: 'Training', value: 977029 },
    { name: 'Write-offs', value: 85712 }
  ];

  // Profit Comparison Data
  const profitData = [
    { name: 'Operating Revenue', value: 330875293 },
    { name: 'Operating Expenses', value: 187703537 },
    { name: 'Operating Profit', value: 143171756 },
    { name: 'Net Profit After Tax', value: 120824697 }
  ];

  // Time Comparison Data (Last Month vs YTD)
  const timeComparisonData = [
    {
      period: 'Operating Revenue',
      'Last Month': 91821352,
      'Year-to-date': 330875293,
    },
    {
      period: 'Operating Expenses',
      'Last Month': 51894137,
      'Year-to-date': 187703537,
    },
    {
      period: 'Net Profit',
      'Last Month': 40300948,
      'Year-to-date': 143045886,
    }
  ];

  const COLORS = ['#0088FE', '#00C49F', '#FFBB28', '#FF8042', '#8884d8', '#82ca9d', '#ffc658'];

  const formatValue = (value) => {
    return `$${(value / 1000000).toFixed(2)}M`;
  };

  return (
    <div className="w-full space-y-4">
      <Card>
        <CardHeader>
          <CardTitle>Financial Performance Dashboard</CardTitle>
        </CardHeader>
        <CardContent className="space-y-8">
          {/* Operating Expenses Breakdown */}
          <div className="space-y-2">
            <h3 className="text-lg font-semibold">Operating Expenses Breakdown</h3>
            <div className="h-96">
              <PieChart width={800} height={400}>
                <Pie
                  data={expenseData}
                  cx="50%"
                  cy="50%"
                  labelLine={true}
                  label={({ name, value }) => `${name}: ${formatValue(value)}`}
                  outerRadius={150}
                  fill="#8884d8"
                  dataKey="value"
                >
                  {expenseData.map((entry, index) => (
                    <Cell key={`cell-${index}`} fill={COLORS[index % COLORS.length]} />
                  ))}
                </Pie>
                <Tooltip formatter={formatValue} />
                <Legend />
              </PieChart>
            </div>
          </div>

          {/* Profit Metrics */}
          <div className="space-y-2">
            <h3 className="text-lg font-semibold">Profit Metrics</h3>
            <div className="h-96">
              <BarChart
                width={800}
                height={400}
                data={profitData}
                margin={{ top: 20, right: 30, left: 20, bottom: 5 }}
              >
                <CartesianGrid strokeDasharray="3 3" />
                <XAxis dataKey="name" />
                <YAxis tickFormatter={formatValue} />
                <Tooltip formatter={formatValue} />
                <Bar dataKey="value" fill="#8884d8" />
              </BarChart>
            </div>
          </div>

          {/* Time Comparison */}
          <div className="space-y-2">
            <h3 className="text-lg font-semibold">Last Month vs Year-to-date Comparison</h3>
            <div className="h-96">
              <BarChart
                width={800}
                height={400}
                data={timeComparisonData}
                margin={{ top: 20, right: 30, left: 20, bottom: 5 }}
              >
                <CartesianGrid strokeDasharray="3 3" />
                <XAxis dataKey="period" />
                <YAxis tickFormatter={formatValue} />
                <Tooltip formatter={formatValue} />
                <Legend />
                <Bar dataKey="Last Month" fill="#8884d8" />
                <Bar dataKey="Year-to-date" fill="#82ca9d" />
              </BarChart>
            </div>
          </div>
        </CardContent>
      </Card>
    </div>
  );
};

export default FinancialDashboard;
